@@ -44,7 +44,7 @@ enum {
     /** \brief VA/GLX API is used, through vaGetDisplayGLX() entry-point. */
     VA_DISPLAY_GLX      = (VA_DISPLAY_X11 | (1 << 0)),
     /** \brief VA/Android API is used, through vaGetDisplay() entry-point. */
-    VA_DISPLAY_ANDROID  = 0x20,
+    VA_DISPLAY_ANDROID va_deprecated_enum = 0x20,
     /** \brief VA/DRM API is used, through vaGetDisplayDRM() entry-point. */
     VA_DISPLAY_DRM      = 0x30,
     /** \brief VA/DRM API is used, with a render-node device path */
@@ -504,8 +504,16 @@ struct VADriverVTable {
         VACopyObject        *src,           /* in */
         VACopyOption        option          /* in */
     );
+
+    VAStatus(*vaMapBuffer2)(
+        VADriverContextP ctx,
+        VABufferID buf_id,                  /* in */
+        void **pbuf,                        /* out */
+        uint32_t flags                      /* in */
+    );
     /** \brief Reserved bytes for future use, must be zero */
-    unsigned long reserved[54];
+    unsigned long reserved[53];
+
 };
 
 struct VADriverContext {
@@ -654,6 +662,7 @@ struct VADisplayContext {
     VADisplayContextP pNext;
     VADriverContextP pDriverContext;
 
+    /* Deprecated */
     int (*vaIsValid)(
         VADisplayContextP ctx
     );
@@ -662,6 +671,7 @@ struct VADisplayContext {
         VADisplayContextP ctx
     );
 
+    /* Deprecated */
     VAStatus(*vaGetDriverName)(
         VADisplayContextP ctx,
         char **driver_name
@@ -669,25 +679,51 @@ struct VADisplayContext {
 
     void *opaque; /* opaque for display extensions (e.g. GLX) */
     void *vatrace; /* opaque for VA trace context */
+    /* Deprecated */
     void *vafool; /* opaque for VA fool context */
 
     VAMessageCallback error_callback;
     void *error_callback_user_context;
     VAMessageCallback info_callback;
     void *info_callback_user_context;
+
+    /* Deprecated */
     VAStatus(*vaGetNumCandidates)(
         VADisplayContextP ctx,
         int * num_candidates
     );
 
+    /* Deprecated */
     VAStatus(*vaGetDriverNameByIndex)(
         VADisplayContextP ctx,
         char **driver_name,
         int  candidate_index
     );
 
+    /**
+     * \brief Callback to get an array of driver names.
+     *
+     *
+     * The caller must provide a num_drivers
+     * This structure is allocated from libva with calloc().
+     *
+     * @param drivers  An num_drivers sized array of null terminated strings.
+     *                 The array is managed my the caller. The callee will
+     *                 populate the individual driver name strings and the
+     *                 caller must free them.
+     * @param num_driver The number of driver strings contained within drivers.
+     *                   The caller must set that to the size of the drivers
+     *                   array, where the callee will update the value to
+     *                   min(caller num_driver, num_drivers_support).
+     */
+    VAStatus(*vaGetDriverNames)(
+        VADisplayContextP ctx,
+        char **drivers,
+        unsigned *num_drivers
+    );
+
     /** \brief Reserved bytes for future use, must be zero */
-    unsigned long reserved[30];
+    unsigned long reserved[29];
 };
 
 typedef VAStatus(*VADriverInit)(
