@@ -38,6 +38,7 @@ const char *vaProfileStr(VAProfile profile)
         TOSTR(VAProfileH264Main);
         TOSTR(VAProfileH264High);
         TOSTR(VAProfileH264High10);
+        TOSTR(VAProfileH264High422);
         TOSTR(VAProfileVC1Simple);
         TOSTR(VAProfileVC1Main);
         TOSTR(VAProfileVC1Advanced);
@@ -64,6 +65,7 @@ const char *vaProfileStr(VAProfile profile)
         TOSTR(VAProfileHEVCSccMain444);
         TOSTR(VAProfileAV1Profile0);
         TOSTR(VAProfileAV1Profile1);
+        TOSTR(VAProfileAV1Profile2);
         TOSTR(VAProfileHEVCSccMain444_10);
         TOSTR(VAProfileProtected);
         TOSTR(VAProfileVVCMain10);
@@ -153,6 +155,7 @@ const char *vaConfigAttribTypeStr(VAConfigAttribType configAttribType)
         TOSTR(VAConfigAttribEncPerBlockControl);
         TOSTR(VAConfigAttribEncMaxTileRows);
         TOSTR(VAConfigAttribEncMaxTileCols);
+        TOSTR(VAConfigAttribEncVP9);
     case VAConfigAttribTypeMax:
         break;
     }
