@@ -37,6 +37,8 @@ extern int va_trace_flag;
 #define VA_TRACE_FLAG_SURFACE_DECODE  0x8
 #define VA_TRACE_FLAG_SURFACE_ENCODE  0x10
 #define VA_TRACE_FLAG_SURFACE_JPEG    0x20
+#define VA_TRACE_FLAG_SURFACE_VPPOUT  0x80
+
 #define VA_TRACE_FLAG_SURFACE         (VA_TRACE_FLAG_SURFACE_DECODE | \
                                        VA_TRACE_FLAG_SURFACE_ENCODE | \
                                        VA_TRACE_FLAG_SURFACE_JPEG)
@@ -44,6 +46,7 @@ extern int va_trace_flag;
 #define VA_TRACE_FLAG_FTRACE_BUFDATA  (VA_TRACE_FLAG_FTRACE | \
                                        VA_TRACE_FLAG_BUFDATA)
 
+
 #define VA_TRACE_LOG(trace_func,...)            \
     if (va_trace_flag & VA_TRACE_FLAG_LOG) {    \
         trace_func(__VA_ARGS__);                \
@@ -353,7 +356,8 @@ DLL_HIDDEN
 void va_TraceMapBuffer(
     VADisplay dpy,
     VABufferID buf_id,  /* in */
-    void **pbuf     /* out */
+    void **pbuf,     /* out */
+    uint32_t flags  /* in */
 );
 
 
@@ -474,7 +478,6 @@ void va_TracePutSurface(
     unsigned int flags /* de-interlacing flags */
 );
 
-DLL_HIDDEN
 void va_TraceStatus(VADisplay dpy, const char * funcName, VAStatus status);
 
 /** \brief va_TraceEvent
@@ -506,6 +509,14 @@ void va_TraceExportSurfaceHandle(
     uint32_t         flags,
     void             *descriptor);
 
+/** \brief va_TraceDeriveImage
+ * trace derive image */
+DLL_HIDDEN
+void va_TraceDeriveImage(
+    VADisplay dpy,
+    VASurfaceID surface,
+    VAImage *image);
+
 #ifdef __cplusplus
 }
 #endif
